"""
aiogram-forms is an addition for aiogram
which allows you to create different forms
and process user input step by step easily.
"""
from .forms import *
from .dispatcher import EntityDispatcher

dispatcher = EntityDispatcher()
